AbbsTree

Struct AbbsTree 

pub struct AbbsTree(/* private fields */);

Implementations

Source

impl AbbsTree

pub fn new<P: AsRef<Path>>(path: P) -> Self

Opens a ABBS tree at the given path.

pub fn as_path(&self) -> &Path

Returns the path of tree.

pub fn into_path(self) -> PathBuf

Returns the path of tree.

pub fn join<P: AsRef<Path>>(&self, path: P) -> PathBuf

Creates an owned PathBuf with path adjoined to self.

Source

impl AbbsTree

pub fn sections(&self) -> AbbsResult<Vec<SectionName>>

Iterates over sections in the tree, e.g. app-admin and runtime-display.

pub fn package<S: AsRef<str>>( &self, section: &SectionName, name: S, ) -> Option<AbbsSourcePackage>

Creates a source package accessor.

pub fn all_packages(&self) -> AbbsResult<Vec<AbbsSourcePackage>>

Iterates over all source packages and creates accessors.

pub fn section_packages( &self, section: &SectionName, ) -> AbbsResult<Vec<AbbsSourcePackage>>

Iterates over all source packages in a certain section and creates accessors.

pub fn find_package<S: AsRef<str>>( &self, name: S, ) -> AbbsResult<AbbsSourcePackage>

Finds a source package and creates an accessor for it.

pub fn find_subpackage<S: AsRef<str>>( &self, name: S, ) -> AbbsResult<AbbsSubPackage>

Returns a subpackage with the given name.

This will first try to find the package in the source package with the same name. If failed to do so, it will fallback to search the whole tree.

Thus this is a very high-cost operation and you must use it carefully.